from pathlib import Path

import yaml

from losoup.file_operations import local_files
from losoup.models import Software, GitlabSoftware, GithubSoftware


def load_software_list(software_file: Path) -> list[Software]:
    software_yaml = yaml.safe_load(software_file.open())
    software_list = []
    for software in software_yaml.get("software", []):
        match software.get("cvs").lower():
            case "github":
                software_list.append(GithubSoftware(**software))
            case "gitlab":
                software_list.append(GitlabSoftware(**software))
            case _:
                pass
    return software_list


def is_software_to_update(software: Software) -> bool:
    return local_files.LocalFile(software).is_file_absent()


if __name__ == "__main__":
    pass
